@@ -84,9 +84,6 @@ class BaseRecord(object):
 
             setattr(self, field.attname, val)
 
-        if kwargs:
-            raise TypeError("'{}' is an invalid keyword argument for this function".format(kwargs.keys()[0]))
-
     def __len__(self):
         """
         Total length this record will be in a fixed width format.
@@ -146,4 +143,4 @@ def get_field_length(f):
     """
     if isinstance(f, fields.ListField):
         return f.length * len(f.record_class)
-    return f.length
\ No newline at end of file
+    return f.length
